/* 
This program (formats_for_nrbs_trip_waterdays_weighted.sas) creates the formats
catalog for nrbs_trip_waterdays_weighted.sas7bdat.

Instructions for Windows users:

1. Create a folder for your files, e.g. c:\sasfiles
2. Place nrbs_trip_waterdays_weighted.sas7bdat and formats_for_nrbs_trip_waterdays_weighted.sas
   in the folder
3. Edit the libname statement in formats_for_nrbs_trip_waterdays_weighted.sas so that
   it refers to the folder, e.g.: libname library 'c:\sasfiles'
4. Open and run formats_for_nrbs_trip_waterdays_weighted.sas.  This will create
   the formats catalog, "formats.sas7bcat" in that folder.
5. You may now use nrbs_trip_waterdays_weighted.sas7bdat any way you
   like, for example the following program will create a frequency listing:

   libname library 'c:\sasfiles';
   proc freq data=library.nrbs_trip_waterdays_weighted; 
      tables _all_;
   run;

   Note that by using the name "library" for your libname when inputting the 
   data, SAS will automatically look in that same location for the formats
   catalog.  Otherwise, you would need to use a "fmtsearch" option to tell
   SAS where to look for the formats catalog.
*/

libname library '';

proc format library=library;

   value YNDKNA 
      1 = "01-YES"
      2 = "02-NO"
      88 = "88-[WEB] NO ANSWER"
      97 = "97-[PHONE] DON'T KNOW"
      99 = "99-[PHONE] REFUSED"
   ;
   value DKRTWO 
      97 = "97-[PHONE] DON'T KNOW"
      99 = "99-[PHONE] REFUSED"
   ;
   value NOANS 
      88 = "88-NO ANSWER"
   ;
   value V00001F 
      1 = "01-YES"
      2 = "02-NO"
      97 = "97-[PHONE] DON'T KNOW"
      99 = "99-[PHONE] REFUSED"
   ;
   value V00002F 
      1 = "01-CONTINUE"
   ;
   value YNDKR 
      1 = "1-YES"
      2 = "2-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00004F 
      1 = "1-[WKIDS_1]"
      2 = "2-[CALCULATION]"
   ;
   value V00005F 
      1 = "1-[WKIDS_2]"
      2 = "2-[CALCULATION]"
   ;
   value V00006F 
      1 = "1-DAY"
      2 = "2-FIRST DAY"
      3 = "3-LAST DAY"
   ;
   value V00007F 
      1 = "1-NEXT DAY"
      2 = "2-PREVIOUS DAY"
      3 = "3-DAY"
   ;
   value V00010F 
      61 = "61-Reported No Activity"
      62 = "62-Reported Docked Day Only"
      63 = "63-Reported Water Day Only"
      64 = "64-Reported Water And Docked Day"
   ;
   value DKRNATWO 
      88 = "88-[WEB] NO ANSWER"
      97 = "97-[PHONE] DON'T KNOW"
      99 = "99-[PHONE] REFUSED"
   ;
   value V00012F 
      1 = "01-AM"
      2 = "02-PM"
      88 = "88-[WEB] NO ANSWER"
      97 = "97-[PHONE] DON'T KNOW"
      99 = "99-[PHONE] REFUSED"
   ;
   value DKRTHREE 
      997 = "997-[PHONE] DON'T KNOW"
      999 = "999-[PHONE] REFUSED"
   ;
   value DKRFOUR 
      9997 = "9997-[PHONE] DON'T KNOW"
      9999 = "9999-[PHONE] REFUSED"
   ;
   value BTACTIVEF 
      0 = "0- BOAT REPORTED NO ACTIVITY IN REFERENCE MONTH"
      1 = "1- BOAT REPORTED AT LEAST ONE DAY OF ACTIVITY IN REFERENCE MONTH"
   ;
   value OUTSTATEF 
      0 = "0- BOAT DID NOT TRAVEL OUT OF STATE"
      1 = "1- BOAT TRAVELED OUT OF STATE"
   ;
   value V00014F 
      1 = "01-YES"
   ;
   value V00015F 
      1 = "01-YES [CONTINUE]"
      2 = "02-NO"
   ;
   value V00019F 
      1 = "01-A LAUNCH SITE OPERATED BY A STATE BOATING OR FISHING AGENCY"
      2 = "02-A LAUNCH SITE OPERATED BY A COUNTY OR LOCAL GOVERNMENT"
      3 = "03-A LAUNCH SITE OPERATED BY A FEDERAL AGENCY"
      4 = "04-A LAUNCH SITE AT A MARINA OR DRY STACK"
      5 = "05-A PRIVATELY OWNED/OPERATED LAUNCH SITE"
      88 = "88-[WEB] NO ANSWER"
      97 = "97-[PHONE] DON'T KNOW"
      99 = "99-[PHONE] REFUSED"
   ;
   value DKR 
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00020F 
      1 = "01-RECORD RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00011F 
      1 = "01-ALABAMA"
      2 = "02-ALASKA"
      4 = "04-ARIZONA"
      5 = "05-ARKANSAS"
      6 = "06-CALIFORNIA"
      8 = "08-COLORADO"
      9 = "09-CONNECTICUT"
      10 = "10-DELAWARE"
      11 = "11-WASHINGTON, DC"
      12 = "12-FLORIDA"
      13 = "13-GEORGIA"
      15 = "15-HAWAII"
      16 = "16-IDAHO"
      17 = "17-ILLINOIS"
      18 = "18-INDIANA"
      19 = "19-IOWA"
      20 = "20-KANSAS"
      21 = "21-KENTUCKY"
      22 = "22-LOUISIANA"
      23 = "23-MAINE"
      24 = "24-MARYLAND"
      25 = "25-MASSACHUSETTS"
      26 = "26-MICHIGAN"
      27 = "27-MINNESOTA"
      28 = "28-MISSISSIPPI"
      29 = "29-MISSOURI"
      30 = "30-MONTANA"
      31 = "31-NEBRASKA"
      32 = "32-NEVADA"
      33 = "33-NEW HAMPSHIRE"
      34 = "34-NEW JERSEY"
      35 = "35-NEW MEXICO"
      36 = "36-NEW YORK"
      37 = "37-NORTH CAROLINA"
      38 = "38-NORTH DAKOTA"
      39 = "39-OHIO"
      40 = "40-OKLAHOMA"
      41 = "41-OREGON"
      42 = "42-PENNSYLVANIA"
      44 = "44-RHODE ISLAND"
      45 = "45-SOUTH CAROLINA"
      46 = "46-SOUTH DAKOTA"
      47 = "47-TENNESSEE"
      48 = "48-TEXAS"
      49 = "49-UTAH"
      50 = "50-VERMONT"
      51 = "51-VIRGINIA"
      53 = "53-WASHINGTON"
      54 = "54-WEST VIRGINIA"
      55 = "55-WISCONSIN"
      56 = "56-WYOMING"
      72 = "72-PUERTO RICO"
      88 = "88-THE BOAT WAS NOT IN THE UNITED STATES"
      96 = "96-OTHER (SPECIFY)"
      97 = "97-[PHONE] DON'T KNOW"
      98 = "98-[WEB] NO ANSWER"
      99 = "99-[PHONE] REFUSED"
   ;
   value NATION 
      1 = "1- UNITED STATES"
   ;
   value V00023F 
      1 = "01-SUCCESSFUL TRANSFER"
      2 = "02-[PHONE] REFUSE TO TRANSFER"
      3 = "03-[PHONE] CALLBACK TO COMPLETE"
   ;
   value V00024F 
      1 = "01-5 OR YOUNGER,"
      2 = "02-6 TO 10,"
      3 = "03-11 TO 15,"
      4 = "04-16 TO 17,"
      5 = "05-18 TO 24,"
      6 = "06-25 TO 34,"
      7 = "07-35 TO 44,"
      8 = "08-45 TO 54,"
      9 = "09-55 TO 64, OR"
      10 = "10-OVER 65"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00025F 
      1 = "01-VERY EXPERIENCED"
      2 = "02-SOMEWHAT EXPERIENCED"
      3 = "03-SOMEWHAT INEXPERIENCED, OR"
      4 = "04-VERY INEXPERIENCED"
      88 = "88-[WEB] NO ANSWER"
      97 = "97-[PHONE] DON'T KNOW"
      99 = "99-[PHONE] REFUSED"
   ;
   value PLFJI_1F 
      1 = "1-YES"
      2 = "2-NO"
      88 = "88-NO ANSWER"
   ;
   value PLFJII_1F 
      1 = "1-YES"
      2 = "2-NO"
      88 = "88-NO ANSWER"
   ;
   value PLFJIII_1F 
      1 = "1-YES"
      2 = "2-NO"
      88 = "88-NO ANSWER"
   ;
   value PLFJIV_1F 
      1 = "1-YES"
      2 = "2-NO"
      88 = "88-NO ANSWER"
   ;
   value PLFJV_1F 
      1 = "1-YES"
      2 = "2-NO"
      88 = "88-NO ANSWER"
   ;
   value V00030F 
      1 = "01-YES"
      99 = "99-REFUSED"
   ;
   value QUARTER 
      1 = "1- Q1"
      2 = "2- Q2"
      3 = "3- Q3"
      4 = "4- Q4"
   ;
   value V00204F 
      1 = "01-REGISTERED/YES"
      2 = "02-UNREGISTERED/NO"
      88 = "88-INVALID RESPONSE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED/MISSING"
   ;
   value REGION 
      1 = "1- NORTHEAST"
      2 = "2- MIDWEST"
      3 = "3- SOUTH"
      4 = "4- WEST"
      9 = "9- PUERTO RICO"
   ;
   value YESNONA 
      1 = "1-YES"
      2 = "2-NO"
      88 = "88-NO ANSWER"
   ;
   value V00035F 
      1 = "01-A 1st AID KIT"
      2 = "02-EQUIPMENT FOR REACHING SOMEONE IN THE WATER"
      3 = "03-A FIRE EXTINGUISHER"
      4 = "04-VISUAL DISTRESS SIGNALS SUCH AS FLARES"
      5 = "05-A SOUND SIGNAL SUCH AS A HORN"
      6 = "06-AN EMERGENCY POSITION INDICATING RADIO BEACON-EPIRB"
      88 = "88- NONE"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00036F 
      1 = "01-FIRST AID KIT"
      2 = "02-EQUIPMENT FOR REACHING SOMEONE IN THE WATER"
      3 = "03-FIRE EXTINGUISHER"
      4 = "04-VISUAL DISTRESS SIGNALS"
      5 = "05-SOUND SIGNALS"
      6 = "06-EMERGENCY POSITION INDICATING RADIO BEACON-EPIRB"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value V00054F 
      1 = "01-MY PERMANENT WATERFRONT HOME"
      2 = "02-MY PERMANENT NON-WATERFRONT HOME"
      3 = "03-MY WATERFRONT 2nd HOME OR COTTAGE"
      4 = "04-MY NON-WATERFRONT 2nd HOME OR COTTAGE"
      5 = "05-FRIEND OR RELATIVE'S WATERFRONT HOME"
      6 = "06-FRIEND OR RELATIVE'S NON-WATERFRONT HOME"
      7 = "07-MARINA, YACHT CLUB, OR DRYSTACK"
      8 = "08-NON-WATERFRONT STORAGE FACILITY"
      9 = "09-OTHER LOCATION"
      88 = "88-[WEB] NO ANSWER"
      97 = "97-[PHONE] DON'T KNOW"
      99 = "99-[PHONE] REFUSED"
   ;
   value V00055F 
      1 = "01-WITH FRIENDS OR FAMILY"
      2 = "02-AT A BED AND BREAKFAST"
      3 = "03-AT A HOTEL OR MOTEL"
      4 = "04-AT A CAMPGROUND, OR"
      5 = "05-ON BOARD THE BOAT"
      88 = "88-[WEB] NO ANSWER"
      97 = "97-[PHONE] DON'T KNOW"
      99 = "99-[PHONE] REFUSED"
   ;
   value PRESENT 
      1 = "1-PRESENT"
      2 = "2-NOT PRESENT"
   ;
   value V00062F 
      1 = "01-LAKE"
      2 = "02-BAY"
      3 = "03-RIVER"
      4 = "04-CANAL"
      5 = "05-INTERCOASTAL WATERWAY"
      6 = "06-OCEAN"
      7 = "07-OTHER (SPECIFY)"
      88 = "88-[WEB] NO ANSWER"
      97 = "97-[PHONE] DON'T KNOW"
      99 = "99-[PHONE] REFUSED"
   ;
   value V00064F 
      1 = "01-FRESHWATER?"
      2 = "02-SALTWATER?"
      3 = "03-BRACKISH WATER?"
      88 = "88-[WEB] NO ANSWER"
      97 = "97-[PHONE] DON'T KNOW"
      99 = "99-[PHONE] REFUSED"
   ;
   value V00067F 
      1 = "01-YES - RECORD NUMBER"
      2 = "02-NO"
      97 = "97-DON'T KNOW"
      99 = "99-REFUSED"
   ;
   value $BOATTYPE 
      "01" = "01- POWERBOAT THAT IS LESS THAN 16 FEET"
      "02" = "02- 16-20 FOOT POWERBOAT"
      "03" = "03- 21-28 FOOT POWERBOAT"
      "04" = "04- POWERBOAT THAT IS GREATER THAN 28 FEET"
      "05" = "05- SAILBOAT THAT IS LESS THAN 26 FEET"
      "06" = "06- SAILBOAT THAT IS GREATER THAN 25 FEET"
      "07" = "07- PONTOON BOAT"
      "08" = "08- PERSONAL WATER CRAFT (FOR EXAMPLE, JET SKI)"
      "09" = "09- SELF PROPELLED BOAT (FOR EXAMPLE, KAYAK, CANOE, ETC.)"
      "10" = "10- RECREATIONAL BOAT"
   ;
   value $BOATTYPE1F 
      "01" = "01- ALL TYPES"
   ;
   value $BOATTYPE10F 
      "01" = "01- POWERBOAT THAT IS LESS THAN 16 FEET"
      "02" = "02- 16-20 FOOT POWERBOAT"
      "03" = "03- 21-28 FOOT POWERBOAT"
      "04" = "04- POWERBOAT THAT IS GREATER THAN 28 FEET"
      "05" = "05- SAILBOAT THAT IS LESS THAN 26 FEET"
      "06" = "06- SAILBOAT THAT IS GREATER THAN 25 FEET"
      "07" = "07- PONTOON BOAT"
      "08" = "08- PERSONAL WATER CRAFT (FOR EXAMPLE, JET SKI)"
      "09" = "09- SELF PROPELLED BOAT (FOR EXAMPLE, KAYAK, CANOE, ETC.)"
      "10" = "10- RECREATIONAL BOAT"
   ;
   value $BOATTYPE3F 
      "01" = "01- POWERBOAT/PONTOON BOAT/PWC"
      "02" = "02- CANOE/KAYAK"
      "03" = "03- SAILBOAT/ROW/INF/OTHER"
   ;
   value $BOATTYPE7F 
      "01" = "01- POWERBOAT"
      "02" = "02- SAILBOAT"
      "03" = "03- PONTOON BOAT"
      "04" = "04- PWC"
      "05" = "05- CANOE"
      "06" = "06- KAYAK"
      "07" = "07- ROW/INF/OTHER"
   ;
   value $CATX 
      "01" = "01-A POWERBOAT"
      "02" = "02-A SAILBOAT"
      "03" = "03-A PERSONAL WATERCRAFT SUCH AS A JET SKI"
      "04" = "04-CANOE"
      "05" = "05-KAYAK"
      "06" = "06-SOMETHING ELSE"
      "97" = "97-DON'T KNOW"
      "99" = "99-REFUSED"
   ;
   value $HASMOT 
      "01" = "01-YES"
      "02" = "02-NO"
      "97" = "97-DON'T KNOW"
      "99" = "99-REFUSED"
   ;
   value $MODE 
      "P" = "P-PHONE"
      "W" = "W-WEB"
   ;
   value $MONTH 
      "01" = "01-JANUARY"
      "02" = "02-FEBRUARY"
      "03" = "03-MARCH"
      "04" = "04-APRIL"
      "05" = "05-MAY"
      "06" = "06-JUNE"
      "07" = "07-JULY"
      "08" = "08-AUGUST"
      "09" = "09-SEPTEMBER"
      "10" = "10-OCTOBER"
      "11" = "11-NOVEMBER"
      "12" = "12-DECEMBER"
   ;
   value $TPOX 
      "01" = "01-A ROWBOAT"
      "02" = "02-AN INFLATABLE"
      "03" = "03-NEITHER"
      "97" = "97-DON'T KNOW"
      "99" = "99-REFUSED"
   ;
run;
